package abstractBeans;

import javax.faces.event.ActionEvent;

import org.eclnt.jsfserver.elements.impl.FIXGRIDBinding.TextSearcher;
import org.eclnt.jsfserver.elements.impl.FIXGRIDItem;
import org.eclnt.jsfserver.elements.impl.FIXGRIDListBinding;
import org.eclnt.jsfserver.pagebean.PageBean;

/**
 * Class to inherit from for concrete beans in order to have less redundancy.
 * I'm Aware that this violates composition over inheritance, but this is no
 * problem in this demo.
 * 
 * @author bjoern
 */
public abstract class TwoColumnTiledAreaBindingBean extends PageBean {

	/**
	 * Text for dynamic menu item for case sensitivity toggle in grid text
	 * searcher.
	 * 
	 * @return
	 */
	public String getCaseSensitivityToggleText() {
		// Of course, if you were in a real application, you'd like to do
		// internationalization in the JSP and not in Java code, so you would
		// not have programmmed something generic as this.
		@SuppressWarnings("rawtypes")
		TextSearcher textSearcher = m_sampleGridBinding.getTextSearcher();
		boolean caseSensitive = textSearcher.getCaseSensitive();
		// this should be the opposite of what is currently set.
		String offOrOn = caseSensitive ? "off" :  "on";
		return "Switch Case Sensitivity " + offOrOn;
	}
	
	public void setCaseSensitivityToggleText() {
		// Nothing to do ...
	}

	/**
	 * Toggle case sensitivity of Grid Text Searcher.
	 * 
	 * @param event
	 *            ignored
	 */
	public void toggleCaseSensitivity(ActionEvent event) {
		@SuppressWarnings("rawtypes")
		TextSearcher textSearcher = m_sampleGridBinding.getTextSearcher();
		textSearcher.setCaseSensitive(!textSearcher.getCaseSensitive());
	}

	/**
	 * Constructor which fills the Grid with dummy values.
	 */
	public TwoColumnTiledAreaBindingBean() {
		m_sampleGridBinding = new FIXGRIDListBinding<TwoColumnTiledAreaBindingBean.SampleGridBindingItem>();
		for (int i = 0; i < 10; i++) {
			String m_column1 = this.getClass().getCanonicalName() + "+C1" + "_"
					+ i;
			String m_column2 = this.getClass().getCanonicalName() + "+C2" + "_"
					+ i;
			SampleGridBindingItem item = new SampleGridBindingItem(m_column1,
					m_column2);
			m_sampleGridBinding.getItems().add(item);
		}
	}

	/**
	 * Grid Binding for JSP Grid
	 */
	FIXGRIDListBinding<SampleGridBindingItem> m_sampleGridBinding = new FIXGRIDListBinding<SampleGridBindingItem>();

	public FIXGRIDListBinding<SampleGridBindingItem> getSampleGridBinding() {
		return m_sampleGridBinding;
	}

	public void setSampleGridBinding(
			FIXGRIDListBinding<SampleGridBindingItem> value) {
		this.m_sampleGridBinding = value;
	}

	/**
	 * Primitive Item for Grid item (grid line). Simply holds two String
	 * Parameters for demo purposes.
	 * 
	 * @author bjoern
	 */
	public class SampleGridBindingItem extends FIXGRIDItem implements
			java.io.Serializable {

		/**
		 * To avoid having to use setters for initialization, use a constructor,
		 * to fill all attributes.
		 * 
		 * @param m_column1
		 *            first value.
		 * @param m_column2
		 *            second value.
		 */
		public SampleGridBindingItem(String m_column1, String m_column2) {
			super();
			this.m_column1 = m_column1;
			this.m_column2 = m_column2;
		}

		private static final long serialVersionUID = 1L;

		/**
		 * Second column.
		 */
		String m_column2;

		public String getColumn2() {
			return m_column2;
		}

		public void setColumn2(String value) {
			this.m_column2 = value;
		}

		/**
		 * First column.
		 */
		String m_column1;

		public String getColumn1() {
			return m_column1;
		}

		public void setColumn1(String value) {
			this.m_column1 = value;
		}

	}
}
